@@ -1,5 +1,5 @@
 /*
-% Copyright (C) 2003-2018 GraphicsMagick Group
+% Copyright (C) 2003-2025 GraphicsMagick Group
 % Copyright (C) 2002 ImageMagick Studio
 %
 % This program is covered by multiple licenses, which are described in
@@ -192,7 +192,7 @@ static MagickPassFail DecodeImage(Image *image,const unsigned long compression,
     (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                           "  Decoding RLE compressed pixels to"
                           " %" MAGICK_SIZE_T_F "u bytes",
-                          image->rows*image->columns);
+                          (MAGICK_SIZE_T) image->rows*(size_t)image->columns);
 
   byte=0;
   x=0;
@@ -215,7 +215,8 @@ static MagickPassFail DecodeImage(Image *image,const unsigned long compression,
                                   "  Decode buffer full (y=%lu, "
                                   "pixels_size=%" MAGICK_SIZE_T_F "u, "
                                   "pixels=%p, q=%p, end=%p)",
-                                  y, (MAGICK_SIZE_T) pixels_size, pixels, q, end);
+                                  y, (MAGICK_SIZE_T) pixels_size,
+                                  pixels, q, end);
           break;
         }
       count=ReadBlobByte(image);
@@ -271,7 +272,7 @@ static MagickPassFail DecodeImage(Image *image,const unsigned long compression,
                 */
                 x=0;
                 y++;
-                q=pixels+y*image->columns;
+                q=pixels+(size_t) y*image->columns;
                 break;
               }
             case 0x02:
@@ -287,7 +288,7 @@ static MagickPassFail DecodeImage(Image *image,const unsigned long compression,
                 if (byte == EOF)
                   return MagickFail;
                 y+=byte;
-                q=pixels+y*image->columns+x;
+                q=pixels+y*(size_t) image->columns+x;
                 break;
               }
             default:
@@ -395,16 +396,16 @@ static MagickPassFail DecodeImage(Image *image,const unsigned long compression,
 %
 %
 */
-static size_t EncodeImage(Image *image,const unsigned long bytes_per_line,
+static size_t EncodeImage(Image *image,const size_t bytes_per_line,
   const unsigned char *pixels,unsigned char *compressed_pixels)
 {
-  long
+  unsigned long
     y;
 
   register const unsigned char
     *p;
 
-  register long
+  register unsigned long
     i,
     x;
 
@@ -420,14 +421,14 @@ static size_t EncodeImage(Image *image,const unsigned long bytes_per_line,
   p=pixels;
   q=compressed_pixels;
   i=0;
-  for (y=0; y < (long) image->rows; y++)
+  for (y=0; y < image->rows; y++)
   {
-    for (x=0; x < (long) bytes_per_line; x+=i)
+    for (x=0; x < bytes_per_line; x+=i)
     {
       /*
         Determine runlength.
       */
-      for (i=1; ((x+i) < (long) bytes_per_line); i++)
+      for (i=1; (((size_t) x+i) < bytes_per_line); i++)
         if ((*(p+i) != *p) || (i == 255U))
           break;
       *q++=(unsigned char) i;
@@ -450,7 +451,7 @@ static size_t EncodeImage(Image *image,const unsigned long bytes_per_line,
   */
   *q++=0;
   *q++=0x01;
-  return(q-compressed_pixels);
+  return((size_t) (q-compressed_pixels));
 }
 
 /*
@@ -552,6 +553,9 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register unsigned char
     *p;
 
+  TimerInfo
+    timer;
+
   size_t
     count,
     length;
@@ -577,6 +581,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info->signature == MagickSignature);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
+  GetTimerInfo(&timer);
   image=AllocateImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == False)
@@ -594,7 +599,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
 
   /*
-    BMP v3 defines width and hight as signed LONG (32 bit) values.  If
+    BMP v3 defines width and height as signed LONG (32 bit) values.  If
     height is a positive number, then the image is a "bottom-up"
     bitmap with origin in the lower-left corner.  If height is a
     negative number, then the image is a "top-down" bitmap with the
@@ -683,7 +688,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       unsigned char
         *dib_colormap;
 
-      unsigned int
+      size_t
         packet_size;
 
       /*
@@ -691,7 +696,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       */
       if (!AllocateImageColormap(image,image->colors))
         ThrowReaderException(ResourceLimitError,MemoryAllocationFailed,image);
-      dib_colormap=MagickAllocateArray(unsigned char *,image->colors,4);
+      dib_colormap=MagickAllocateResourceLimitedArray(unsigned char *,image->colors,4);
       if (dib_colormap == (unsigned char *) NULL)
         ThrowReaderException(ResourceLimitError,MemoryAllocationFailed,image);
       packet_size=4;
@@ -704,7 +709,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
                                   " (expected %" MAGICK_SIZE_T_F  "u bytes)",
                                   (MAGICK_SIZE_T) count,
                                   (MAGICK_SIZE_T) packet_size*image->colors);
-          MagickFreeMemory(dib_colormap);
+          MagickFreeResourceLimitedMemory(dib_colormap);
           ThrowReaderException(CorruptImageError,UnexpectedEndOfFile,image);
         }
       p=dib_colormap;
@@ -716,7 +721,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (packet_size == 4)
           p++;
       }
-      MagickFreeMemory(dib_colormap);
+      MagickFreeResourceLimitedMemory(dib_colormap);
     }
   /*
     Read image data.
@@ -760,12 +765,12 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   length=MagickArraySize(bytes_per_line,image->rows);
   if (length == 0)
     ThrowReaderException(CoderError,ArithmeticOverflow,image);
-  if (~((size_t) 0) - image->columns < 1)
+  if ((image->columns+1UL) < image->columns)
     ThrowReaderException(CoderError,ArithmeticOverflow,image);
   pixels_size=MagickArraySize(image->rows,Max(bytes_per_line,(size_t) image->columns+1));
   if (pixels_size == 0)
     ThrowReaderException(CoderError,ArithmeticOverflow,image);
-  pixels=MagickAllocateMemory(unsigned char *,pixels_size);
+  pixels=MagickAllocateResourceLimitedMemory(unsigned char *,pixels_size);
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,MemoryAllocationFailed,image);
   if ((dib_info.compression == 0) || (dib_info.compression == 3))
@@ -778,7 +783,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
                                   " (expected %" MAGICK_SIZE_T_F  "u bytes)",
                                   (MAGICK_SIZE_T) count,
                                   (MAGICK_SIZE_T) length);
-          MagickFreeMemory(pixels);
+          MagickFreeResourceLimitedMemory(pixels);
           ThrowReaderException(CorruptImageError,UnexpectedEndOfFile,image);
         }
     }
@@ -791,10 +796,10 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       */
       (void) memset(pixels,0,pixels_size);
       status=DecodeImage(image,dib_info.compression,pixels,
-                         image->rows*image->columns);
+                         (size_t) image->rows*image->columns);
       if (status == False)
         {
-          MagickFreeMemory(pixels);
+          MagickFreeResourceLimitedMemory(pixels);
           ThrowReaderException(CorruptImageError,UnableToRunlengthDecodeImage,
                                image);
         }
@@ -817,7 +822,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       */
       for (y=(long) image->rows-1; y >= 0; y--)
       {
-        p=pixels+(image->rows-y-1)*bytes_per_line;
+        p=pixels+((size_t) image->rows-y-1)*bytes_per_line;
         q=SetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
@@ -849,7 +854,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (image->previous == (Image *) NULL)
           if (QuantumTick(y,image->rows))
             {
-              status=MagickMonitorFormatted(image->rows-y-1,image->rows,
+              status=MagickMonitorFormatted((size_t) image->rows-y-1,image->rows,
                                             exception,LoadImageText,
                                             image->filename,
                                             image->columns,image->rows);
@@ -866,7 +871,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       */
       for (y=(long) image->rows-1; y >= 0; y--)
       {
-        p=pixels+(image->rows-y-1)*bytes_per_line;
+        p=pixels+((size_t) image->rows-y-1)*bytes_per_line;
         q=SetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
@@ -896,7 +901,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (image->previous == (Image *) NULL)
           if (QuantumTick(y,image->rows))
             {
-              status=MagickMonitorFormatted(image->rows-y-1,image->rows,
+              status=MagickMonitorFormatted((size_t) image->rows-y-1,image->rows,
                                             exception,LoadImageText,
                                             image->filename,
                                             image->columns,image->rows);
@@ -915,7 +920,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         bytes_per_line=image->columns;
       for (y=(long) image->rows-1; y >= 0; y--)
       {
-        p=pixels+(image->rows-y-1)*bytes_per_line;
+        p=pixels+((size_t) image->rows-y-1)*bytes_per_line;
         q=SetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
@@ -934,7 +939,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (image->previous == (Image *) NULL)
           if (QuantumTick(y,image->rows))
             {
-              status=MagickMonitorFormatted(image->rows-y-1,image->rows,
+              status=MagickMonitorFormatted((size_t) image->rows-y-1,image->rows,
                                             exception,LoadImageText,
                                             image->filename,
                                             image->columns,image->rows);
@@ -954,10 +959,10 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       */
       image->storage_class=DirectClass;
       if (dib_info.compression == 1)
-        bytes_per_line=2*image->columns;
+        bytes_per_line=(size_t) 2*image->columns;
       for (y=(long) image->rows-1; y >= 0; y--)
       {
-        p=pixels+(image->rows-y-1)*bytes_per_line;
+        p=pixels+((size_t) image->rows-y-1)*bytes_per_line;
         q=SetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
@@ -984,7 +989,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (image->previous == (Image *) NULL)
           if (QuantumTick(y,image->rows))
             {
-              status=MagickMonitorFormatted(image->rows-y-1,image->rows,
+              status=MagickMonitorFormatted((size_t) image->rows-y-1,image->rows,
                                             exception,LoadImageText,
                                             image->filename,
                                             image->columns,image->rows);
@@ -1002,7 +1007,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       */
       for (y=(long) image->rows-1; y >= 0; y--)
       {
-        p=pixels+(image->rows-y-1)*bytes_per_line;
+        p=pixels+((size_t) image->rows-y-1)*bytes_per_line;
         q=SetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
@@ -1020,7 +1025,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (image->previous == (Image *) NULL)
           if (QuantumTick(y,image->rows))
             {
-              status=MagickMonitorFormatted(image->rows-y-1,image->rows,
+              status=MagickMonitorFormatted((size_t) image->rows-y-1,image->rows,
                                             exception,LoadImageText,
                                             image->filename,
                                             image->columns,image->rows);
@@ -1032,11 +1037,11 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
     default:
       {
-        MagickFreeMemory(pixels);
+        MagickFreeResourceLimitedMemory(pixels);
         ThrowReaderException(CorruptImageError,ImproperImageHeader,image);
       }
   }
-  MagickFreeMemory(pixels);
+  MagickFreeResourceLimitedMemory(pixels);
   if (EOFBlob(image))
     ThrowException(exception,CorruptImageError,UnexpectedEndOfFile,
                    image->filename);
@@ -1097,7 +1102,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           if (image->previous == (Image *) NULL)
             if (QuantumTick(y,image->rows))
-              if (!MagickMonitorFormatted(image->rows-y-1,image->rows,&image->exception,
+              if (!MagickMonitorFormatted((size_t) image->rows-y-1,image->rows,&image->exception,
                                           LoadImageText,image->filename,
                                           image->columns,image->rows))
                 break;
@@ -1125,7 +1130,6 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     {
       Image
         *flipped_image;
-
       /*
         Correct image orientation.
       */
@@ -1141,6 +1145,8 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image=flipped_image;
     }
   CloseBlob(image);
+  StopTimer(&timer);
+  image->timer=timer;
   return(image);
 }
 
@@ -1177,7 +1183,9 @@ ModuleExport void RegisterDIBImage(void)
   entry->encoder=(EncoderHandler) WriteDIBImage;
   entry->magick=(MagickHandler) IsDIB;
   entry->adjoin=False;
-  entry->stealth=True;
+#if !defined(FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION)
+  entry->stealth=True; /* Don't list in '-list format' output */
+#endif /* if !defined(FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION) */
   entry->description="Microsoft Windows 3.X Packed Device-Independent Bitmap";
   entry->module="DIB";
   (void) RegisterMagickInfo(entry);
@@ -1187,7 +1195,7 @@ ModuleExport void RegisterDIBImage(void)
   /* entry->encoder=(EncoderHandler) WriteDIBImage; */
   entry->magick=(MagickHandler) IsDIB;
   entry->adjoin=False;
-  entry->stealth=True;
+  entry->stealth=True; /* Don't list in '-list format' output */
   entry->raw=True; /* Requires size to work correctly. */
   entry->description="Microsoft Windows 3.X Packed Device-Independent Bitmap + Mask";
   entry->module="DIB";
@@ -1255,7 +1263,7 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
   DIBInfo
     dib_info;
 
-  long
+  unsigned long
     y;
 
   register const PixelPacket
@@ -1264,7 +1272,7 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
   register const IndexPacket
     *indexes;
 
-  register long
+  register unsigned long
     i,
     x;
 
@@ -1278,8 +1286,9 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
   unsigned int
     status;
 
-  unsigned long
-    bytes_per_line;
+  size_t
+    bytes_per_line,
+    image_size;
 
   ImageCharacteristics
     characteristics;
@@ -1338,12 +1347,15 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
     bytes_per_line = MagickArraySize(4,(bytes_per_line+31)/32);
   if (bytes_per_line == 0)
     ThrowWriterException(CoderError,ArithmeticOverflow,image);
+  image_size=MagickArraySize(bytes_per_line,image->rows);
+  if ((image_size == 0) || ((image_size & 0xffffffff) != image_size))
+    ThrowWriterException(CoderError,ArithmeticOverflow,image);
   dib_info.header_size=40;
   dib_info.width=(long) image->columns;
   dib_info.height=(long) image->rows;
   dib_info.planes=1;
   dib_info.compression=0;
-  dib_info.image_size=bytes_per_line*image->rows;
+  dib_info.image_size=(magick_uint32_t) image_size;
   dib_info.x_pixels=75*39;
   dib_info.y_pixels=75*39;
   if (image->units == PixelsPerInchResolution)
@@ -1360,7 +1372,7 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
   /*
     Convert MIFF to DIB raster pixels.
   */
-  pixels=MagickAllocateMemory(unsigned char *,dib_info.image_size);
+  pixels=MagickAllocateResourceLimitedMemory(unsigned char *,dib_info.image_size);
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,MemoryAllocationFailed,image);
   switch (dib_info.bits_per_pixel)
@@ -1374,7 +1386,7 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
       /*
         Convert PseudoClass image to a DIB monochrome image.
       */
-      for (y=0; y < (long) image->rows; y++)
+      for (y=0; y < image->rows; y++)
       {
         p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
         if (p == (const PixelPacket *) NULL)
@@ -1383,7 +1395,7 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
         q=pixels+(image->rows-y-1)*bytes_per_line;
         bit=0;
         byte=0;
-        for (x=0; x < (long) image->columns; x++)
+        for (x=0; x < image->columns; x++)
         {
           byte<<=1;
           byte|=indexes[x] ? 0x01 : 0x00;
@@ -1399,7 +1411,7 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
        if (bit != 0)
          *q++=byte << (8-bit);
        /* initialize padding bytes */
-       for (x=(long) (image->columns+7)/8; x < (long) bytes_per_line; x++)
+       for (x=(image->columns+7)/8; x < bytes_per_line; x++)
          *q++=0x00;
        if (image->previous == (Image *) NULL)
          if (QuantumTick(y,image->rows))
@@ -1415,20 +1427,20 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
       /*
         Convert PseudoClass packet to DIB pixel.
       */
-      for (y=0; y < (long) image->rows; y++)
+      for (y=0; y < image->rows; y++)
       {
         p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
         if (p == (const PixelPacket *) NULL)
           break;
         indexes=AccessImmutableIndexes(image);
         q=pixels+(image->rows-y-1)*bytes_per_line;
-        for (x=0; x < (long) image->columns; x++)
+        for (x=0; x < image->columns; x++)
         {
           *q++=indexes[x];
           p++;
         }
        /* initialize padding bytes */
-       for (; x < (long) bytes_per_line; x++)
+       for (; x < bytes_per_line; x++)
          *q++=0x00;
         if (image->previous == (Image *) NULL)
           if (QuantumTick(y,image->rows))
@@ -1445,13 +1457,13 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
       /*
         Convert DirectClass packet to DIB RGB pixel.
       */
-      for (y=0; y < (long) image->rows; y++)
+      for (y=0; y < image->rows; y++)
       {
         p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
         if (p == (const PixelPacket *) NULL)
           break;
         q=pixels+(image->rows-y-1)*bytes_per_line;
-        for (x=0; x < (long) image->columns; x++)
+        for (x=0; x < image->columns; x++)
         {
           *q++=ScaleQuantumToChar(p->blue);
           *q++=ScaleQuantumToChar(p->green);
@@ -1464,7 +1476,7 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
         if (dib_info.bits_per_pixel == 24)
           {
             /* initialize padding bytes */
-            for (x=3*image->columns; x < (long) bytes_per_line; x++)
+            for (x=3*image->columns; x < bytes_per_line; x++)
               *q++=0x00;
           }
         if (image->previous == (Image *) NULL)
@@ -1486,17 +1498,17 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
         /*
           Convert run-length encoded raster pixels.
         */
-        length=2*(bytes_per_line+2)*(image->rows+2)+2;
-        dib_data=MagickAllocateMemory(unsigned char *,length);
+        length=2*((size_t) bytes_per_line+2)*((size_t) image->rows+2)+2;
+        dib_data=MagickAllocateResourceLimitedMemory(unsigned char *,length);
         if (dib_data == (unsigned char *) NULL)
           {
-            MagickFreeMemory(pixels);
+            MagickFreeResourceLimitedMemory(pixels);
             ThrowWriterException(ResourceLimitError,MemoryAllocationFailed,
-              image)
+                                 image);
           }
         dib_info.image_size=(unsigned long)
           EncodeImage(image,bytes_per_line,pixels,dib_data);
-        MagickFreeMemory(pixels);
+        MagickFreeResourceLimitedMemory(pixels);
         pixels=dib_data;
         dib_info.compression=1;
       }
@@ -1522,34 +1534,34 @@ static unsigned int WriteDIBImage(const ImageInfo *image_info,Image *image)
       /*
         Dump colormap to file.
       */
-      dib_colormap=MagickAllocateArray(unsigned char *,
-                                       (size_t) (1U << dib_info.bits_per_pixel),4);
+      dib_colormap=MagickAllocateResourceLimitedArray(unsigned char *,
+                                                      (((size_t) 1U) << dib_info.bits_per_pixel),4);
       if (dib_colormap == (unsigned char *) NULL)
         {
-          MagickFreeMemory(pixels);
+          MagickFreeResourceLimitedMemory(pixels);
           ThrowWriterException(ResourceLimitError,MemoryAllocationFailed,image);
         }
       q=dib_colormap;
-      for (i=0; i < (long) Min(image->colors,dib_info.number_colors); i++)
+      for (i=0; i < Min(image->colors,dib_info.number_colors); i++)
       {
         *q++=ScaleQuantumToChar(image->colormap[i].blue);
         *q++=ScaleQuantumToChar(image->colormap[i].green);
         *q++=ScaleQuantumToChar(image->colormap[i].red);
         *q++=(Quantum) 0x0;
       }
-      for ( ; i < (1L << dib_info.bits_per_pixel); i++)
+      for ( ; i < (1U << dib_info.bits_per_pixel); i++)
       {
         *q++=(Quantum) 0x0;
         *q++=(Quantum) 0x0;
         *q++=(Quantum) 0x0;
         *q++=(Quantum) 0x0;
       }
-      (void) WriteBlob(image,4*(1 << dib_info.bits_per_pixel),
+      (void) WriteBlob(image, 4*(((size_t) 1U) << dib_info.bits_per_pixel),
         (char *) dib_colormap);
-      MagickFreeMemory(dib_colormap);
+      MagickFreeResourceLimitedMemory(dib_colormap);
     }
   (void) WriteBlob(image,dib_info.image_size,(char *) pixels);
-  MagickFreeMemory(pixels);
-  CloseBlob(image);
-  return(True);
+  MagickFreeResourceLimitedMemory(pixels);
+  status &= CloseBlob(image);
+  return(status);
 }
